package com.wordesign.util;

import java.io.*;
import java.util.*;

/**
 * Title:        First Course In Java: examples and HomeWorks
 * Description:  This class is a utility class to read input from the
 *               Command Line
 * 
 * Copyright:    Copyright (c) 2001
 * 
 * @author Thomas Albert
 * @author Alexandre Aybes
 */
public class ConsoleReader
{
	/**
	 * This method reads an integer from the command line, it returns only
	 * once a correct integer has been entered, if the user enters text that
	 * cannot be parsed as an integer, this method will inform the user
	 * and ask for the data again.
	 * @return returns an int that represents the value entered by the user
	 */
	public static int readInt()
	{
		int value = 0;
		boolean done = false;
		while (!done)
		{
			try
			{
				String line = readLine();
				//  get the first token!
				StringTokenizer st = new StringTokenizer(line);
				if (st.hasMoreElements())
				{
					String firstWord = st.nextToken();
					value = Integer.parseInt(firstWord);
					done = true;
				}
			}
			catch (NumberFormatException nfe)
			{
				System.err.println("Number Format Exception: "+nfe);
				System.out.println("Please enter an integer nuber!");
			}
		}
		return value;
	}
	
	/**
	 * This method reads a double value from the command line, it returns only
	 * once a correct double has been entered, if the user enters text that
	 * cannot be parsed as a double, this method will inform the user
	 * and ask for the data again.
	 * @return returns a double that represents the value entered by the user
	 */
	public static double readDouble()
	{
		double value = 0;
		boolean done = false;
		while (!done)
		{
			try
			{
				String line = readLine();
				//  get the first token!
				StringTokenizer st = new StringTokenizer(line);
				if (st.hasMoreElements())
				{
					String firstWord = st.nextToken();
					value = Double.parseDouble(firstWord);
					done = true;
				}
			}
			catch (NumberFormatException nfe)
			{
				System.err.println("Number Format Exception: "+nfe);
				System.out.println("Please enter a decimal number!");
			}
		}
		return value;
	}
	
	/**
	 * This method reads a line of text from the command line, it waits until a
	 * line of text is entered (the user has to press return) and then returns
	 * @return returns the line the user entered, this method does not return
	 *      a null value, but might return an empty string ("").
	 */
	public static String readLine()
	{
		InputStreamReader isr = new InputStreamReader(System.in);
		BufferedReader br = new BufferedReader(isr);
		String line = "";
		try
		{
			line = br.readLine();
			while (line == null)
			{
				line = br.readLine();
			}
		}
		catch (IOException ioe)
		{
			System.err.println("Error reading line: "+ioe);
		}
		return line;
	}
	
	/**
	 * This is a simple test method.
	 */
	public static void main(String[] args)
	{
		int value = -666;
		System.out.print("Enter a number: ");
		value = readInt();
		System.out.println("You entered: "+value);
		System.out.print("Enter a float value: ");
		double fp = readDouble();
		System.out.println("You entered: "+fp);
	}
}